@@ -20,8 +20,13 @@ EXCLUDED_TOKENS = frozenset({
 EXCLUDED_PAIRS = frozenset({
     (tokenize.OP, '('),
     (tokenize.OP, ')'),
+    (tokenize.OP, '['),
+    (tokenize.OP, ']'),
+    (tokenize.OP, '{'),
+    (tokenize.OP, '}'),
     (tokenize.OP, ','),
     (tokenize.OP, ';'),
+    (tokenize.OP, ':'),
 })
 
 
